# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/apps/zuoyepigai/tasktag.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/apps/zuoyepigai/tasktag.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.apps.zuoyepigai import meta_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n(yeying/api/apps/zuoyepigai/tasktag.proto\x12\x1ayeying.api.apps.zuoyepigai\x1a\x1fyeying/api/common/message.proto\x1a%yeying/api/apps/zuoyepigai/meta.proto"\x86\x01\n\x11\x41\x64\x64TaskTagRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12?\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x31.yeying.api.apps.zuoyepigai.AddTaskTagRequestBody"R\n\x15\x41\x64\x64TaskTagRequestBody\x12\x39\n\x04meta\x18\x01 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.TaskTagMetadata"\x88\x01\n\x12\x41\x64\x64TaskTagResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.AddTaskTagResponseBody"\x86\x01\n\x16\x41\x64\x64TaskTagResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04meta\x18\x02 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.TaskTagMetadata"\x8c\x01\n\x14\x44\x65tailTaskTagRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.DetailTaskTagRequestBody"\'\n\x18\x44\x65tailTaskTagRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x8e\x01\n\x15\x44\x65tailTaskTagResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.DetailTaskTagResponseBody"\x89\x01\n\x19\x44\x65tailTaskTagResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04meta\x18\x02 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.TaskTagMetadata"\x88\x01\n\x12ListTaskTagRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.ListTaskTagRequestBody"%\n\x16ListTaskTagRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t"\x8a\x01\n\x13ListTaskTagResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.apps.zuoyepigai.ListTaskTagResponseBody"\x87\x01\n\x17ListTaskTagResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04list\x18\x02 \x03(\x0b\x32+.yeying.api.apps.zuoyepigai.TaskTagMetadata"\x8c\x01\n\x14UpdateTaskTagRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.UpdateTaskTagRequestBody"U\n\x18UpdateTaskTagRequestBody\x12\x39\n\x04meta\x18\x01 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.TaskTagMetadata"\x8e\x01\n\x15UpdateTaskTagResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.UpdateTaskTagResponseBody"\x89\x01\n\x19UpdateTaskTagResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04meta\x18\x02 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.TaskTagMetadata"\x8c\x01\n\x14\x44\x65leteTaskTagRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.DeleteTaskTagRequestBody"\'\n\x18\x44\x65leteTaskTagRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x8e\x01\n\x15\x44\x65leteTaskTagResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.DeleteTaskTagResponseBody"\x89\x01\n\x19\x44\x65leteTaskTagResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04meta\x18\x02 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.TaskTagMetadata2\xaf\x04\n\x07TaskTag\x12\x66\n\x03\x41\x64\x64\x12-.yeying.api.apps.zuoyepigai.AddTaskTagRequest\x1a..yeying.api.apps.zuoyepigai.AddTaskTagResponse"\x00\x12o\n\x06\x44\x65tail\x12\x30.yeying.api.apps.zuoyepigai.DetailTaskTagRequest\x1a\x31.yeying.api.apps.zuoyepigai.DetailTaskTagResponse"\x00\x12i\n\x04List\x12..yeying.api.apps.zuoyepigai.ListTaskTagRequest\x1a/.yeying.api.apps.zuoyepigai.ListTaskTagResponse"\x00\x12o\n\x06Update\x12\x30.yeying.api.apps.zuoyepigai.UpdateTaskTagRequest\x1a\x31.yeying.api.apps.zuoyepigai.UpdateTaskTagResponse"\x00\x12o\n\x06\x44\x65lete\x12\x30.yeying.api.apps.zuoyepigai.DeleteTaskTagRequest\x1a\x31.yeying.api.apps.zuoyepigai.DeleteTaskTagResponse"\x00\x42\x1cZ\x1ayeying/api/apps/zuoyepigaib\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.apps.zuoyepigai.tasktag_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\032yeying/api/apps/zuoyepigai"
    _globals["_ADDTASKTAGREQUEST"]._serialized_start = 145
    _globals["_ADDTASKTAGREQUEST"]._serialized_end = 279
    _globals["_ADDTASKTAGREQUESTBODY"]._serialized_start = 281
    _globals["_ADDTASKTAGREQUESTBODY"]._serialized_end = 363
    _globals["_ADDTASKTAGRESPONSE"]._serialized_start = 366
    _globals["_ADDTASKTAGRESPONSE"]._serialized_end = 502
    _globals["_ADDTASKTAGRESPONSEBODY"]._serialized_start = 505
    _globals["_ADDTASKTAGRESPONSEBODY"]._serialized_end = 639
    _globals["_DETAILTASKTAGREQUEST"]._serialized_start = 642
    _globals["_DETAILTASKTAGREQUEST"]._serialized_end = 782
    _globals["_DETAILTASKTAGREQUESTBODY"]._serialized_start = 784
    _globals["_DETAILTASKTAGREQUESTBODY"]._serialized_end = 823
    _globals["_DETAILTASKTAGRESPONSE"]._serialized_start = 826
    _globals["_DETAILTASKTAGRESPONSE"]._serialized_end = 968
    _globals["_DETAILTASKTAGRESPONSEBODY"]._serialized_start = 971
    _globals["_DETAILTASKTAGRESPONSEBODY"]._serialized_end = 1108
    _globals["_LISTTASKTAGREQUEST"]._serialized_start = 1111
    _globals["_LISTTASKTAGREQUEST"]._serialized_end = 1247
    _globals["_LISTTASKTAGREQUESTBODY"]._serialized_start = 1249
    _globals["_LISTTASKTAGREQUESTBODY"]._serialized_end = 1286
    _globals["_LISTTASKTAGRESPONSE"]._serialized_start = 1289
    _globals["_LISTTASKTAGRESPONSE"]._serialized_end = 1427
    _globals["_LISTTASKTAGRESPONSEBODY"]._serialized_start = 1430
    _globals["_LISTTASKTAGRESPONSEBODY"]._serialized_end = 1565
    _globals["_UPDATETASKTAGREQUEST"]._serialized_start = 1568
    _globals["_UPDATETASKTAGREQUEST"]._serialized_end = 1708
    _globals["_UPDATETASKTAGREQUESTBODY"]._serialized_start = 1710
    _globals["_UPDATETASKTAGREQUESTBODY"]._serialized_end = 1795
    _globals["_UPDATETASKTAGRESPONSE"]._serialized_start = 1798
    _globals["_UPDATETASKTAGRESPONSE"]._serialized_end = 1940
    _globals["_UPDATETASKTAGRESPONSEBODY"]._serialized_start = 1943
    _globals["_UPDATETASKTAGRESPONSEBODY"]._serialized_end = 2080
    _globals["_DELETETASKTAGREQUEST"]._serialized_start = 2083
    _globals["_DELETETASKTAGREQUEST"]._serialized_end = 2223
    _globals["_DELETETASKTAGREQUESTBODY"]._serialized_start = 2225
    _globals["_DELETETASKTAGREQUESTBODY"]._serialized_end = 2264
    _globals["_DELETETASKTAGRESPONSE"]._serialized_start = 2267
    _globals["_DELETETASKTAGRESPONSE"]._serialized_end = 2409
    _globals["_DELETETASKTAGRESPONSEBODY"]._serialized_start = 2412
    _globals["_DELETETASKTAGRESPONSEBODY"]._serialized_end = 2549
    _globals["_TASKTAG"]._serialized_start = 2552
    _globals["_TASKTAG"]._serialized_end = 3111
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/asset/block.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/asset/block.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1cyeying/api/asset/block.proto\x12\x10yeying.api.asset\x1a\x1fyeying/api/common/message.proto"\x80\x01\n\x13\x43onfirmBlockRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.asset.ConfirmBlockRequestBody"I\n\x17\x43onfirmBlockRequestBody\x12.\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x1f.yeying.api.asset.BlockMetadata"\x82\x01\n\x14\x43onfirmBlockResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x38\n\x04\x62ody\x18\x02 \x01(\x0b\x32*.yeying.api.asset.ConfirmBlockResponseBody"}\n\x18\x43onfirmBlockResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12.\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x1f.yeying.api.asset.BlockMetadata"\xd6\x01\n\x15StreamPutBlockRequest\x12;\n\x04head\x18\x02 \x01(\x0b\x32+.yeying.api.asset.StreamPutBlockRequestHeadH\x00\x12;\n\x04\x62ody\x18\x03 \x01(\x0b\x32+.yeying.api.asset.StreamPutBlockRequestBodyH\x00\x12;\n\x04Tail\x18\x04 \x01(\x0b\x32+.yeying.api.asset.StreamPutBlockRequestTailH\x00\x42\x06\n\x04\x64\x61ta"\x8c\x01\n\x19StreamPutBlockRequestHead\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12=\n\x04\x62ody\x18\x02 \x01(\x0b\x32/.yeying.api.asset.StreamPutBlockRequestHeadBody"O\n\x1dStreamPutBlockRequestHeadBody\x12.\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x1f.yeying.api.asset.BlockMetadata")\n\x19StreamPutBlockRequestBody\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c"M\n\x19StreamPutBlockRequestTail\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"\x9c\x01\n\x16StreamPutBlockResponse\x12<\n\x04head\x18\x01 \x01(\x0b\x32,.yeying.api.asset.StreamPutBlockResponseHeadH\x00\x12<\n\x04tail\x18\x02 \x01(\x0b\x32,.yeying.api.asset.StreamPutBlockResponseTailH\x00\x42\x06\n\x04\x64\x61ta"\x8e\x01\n\x1aStreamPutBlockResponseHead\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.asset.StreamPutBlockResponseHeadBody"\x83\x01\n\x1eStreamPutBlockResponseHeadBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12.\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x1f.yeying.api.asset.BlockMetadata"\x8e\x01\n\x1aStreamPutBlockResponseTail\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.asset.StreamPutBlockResponseTailBody"S\n\x1eStreamPutBlockResponseTailBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x86\x01\n\x0fPutBlockRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x33\n\x04\x62ody\x18\x02 \x01(\x0b\x32%.yeying.api.asset.PutBlockRequestBody\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c"E\n\x13PutBlockRequestBody\x12.\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x1f.yeying.api.asset.BlockMetadata"z\n\x10PutBlockResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32&.yeying.api.asset.PutBlockResponseBody"y\n\x14PutBlockResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12.\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x1f.yeying.api.asset.BlockMetadata"x\n\x0fGetBlockRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x33\n\x04\x62ody\x18\x02 \x01(\x0b\x32%.yeying.api.asset.GetBlockRequestBody"8\n\x13GetBlockRequestBody\x12\x13\n\x0bnamespaceId\x18\x01 \x01(\t\x12\x0c\n\x04hash\x18\x02 \x01(\t"\x99\x01\n\x15StreamGetBlockRequest\x12;\n\x04head\x18\x02 \x01(\x0b\x32+.yeying.api.asset.StreamGetBlockRequestHeadH\x00\x12;\n\x04\x62ody\x18\x03 \x01(\x0b\x32+.yeying.api.asset.StreamGetBlockRequestBodyH\x00\x42\x06\n\x04\x64\x61ta"\x8c\x01\n\x19StreamGetBlockRequestHead\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12=\n\x04\x62ody\x18\x02 \x01(\x0b\x32/.yeying.api.asset.StreamGetBlockRequestHeadBody"B\n\x1dStreamGetBlockRequestHeadBody\x12\x13\n\x0bnamespaceId\x18\x01 \x01(\t\x12\x0c\n\x04hash\x18\x02 \x01(\t"M\n\x19StreamGetBlockRequestBody\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"\xda\x01\n\x16StreamGetBlockResponse\x12<\n\x04head\x18\x02 \x01(\x0b\x32,.yeying.api.asset.StreamGetBlockResponseHeadH\x00\x12<\n\x04\x62ody\x18\x03 \x01(\x0b\x32,.yeying.api.asset.StreamGetBlockResponseBodyH\x00\x12<\n\x04tail\x18\x04 \x01(\x0b\x32,.yeying.api.asset.StreamGetBlockResponseTailH\x00\x42\x06\n\x04\x64\x61ta"\x8e\x01\n\x1aStreamGetBlockResponseHead\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.asset.StreamGetBlockResponseHeadBody"\x83\x01\n\x1eStreamGetBlockResponseHeadBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12.\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x1f.yeying.api.asset.BlockMetadata"*\n\x1aStreamGetBlockResponseBody\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c"\x8e\x01\n\x1aStreamGetBlockResponseTail\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.asset.StreamGetBlockResponseTailBody"S\n\x1eStreamGetBlockResponseTailBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"y\n\x14GetBlockResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12.\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x1f.yeying.api.asset.BlockMetadata"\x88\x01\n\x10GetBlockResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32&.yeying.api.asset.GetBlockResponseBody\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c"\x87\x01\n\rBlockMetadata\x12\x13\n\x0bnamespaceId\x18\x01 \x01(\t\x12\x10\n\x08uploader\x18\x02 \x01(\t\x12\r\n\x05owner\x18\x03 \x01(\t\x12\x0c\n\x04hash\x18\x04 \x01(\t\x12\x0c\n\x04size\x18\x05 \x01(\x04\x12\x11\n\tcreatedAt\x18\x06 \x01(\t\x12\x11\n\tsignature\x18\x07 \x01(\t2\xcf\x03\n\x05\x42lock\x12N\n\x03Put\x12!.yeying.api.asset.PutBlockRequest\x1a".yeying.api.asset.PutBlockResponse"\x00\x12\x64\n\tStreamPut\x12\'.yeying.api.asset.StreamPutBlockRequest\x1a(.yeying.api.asset.StreamPutBlockResponse"\x00(\x01\x30\x01\x12Z\n\x07\x43onfirm\x12%.yeying.api.asset.ConfirmBlockRequest\x1a&.yeying.api.asset.ConfirmBlockResponse"\x00\x12N\n\x03Get\x12!.yeying.api.asset.GetBlockRequest\x1a".yeying.api.asset.GetBlockResponse"\x00\x12\x64\n\tStreamGet\x12\'.yeying.api.asset.StreamGetBlockRequest\x1a(.yeying.api.asset.StreamGetBlockResponse"\x00(\x01\x30\x01\x42\x12Z\x10yeying/api/assetb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.asset.block_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\020yeying/api/asset"
    _globals["_CONFIRMBLOCKREQUEST"]._serialized_start = 84
    _globals["_CONFIRMBLOCKREQUEST"]._serialized_end = 212
    _globals["_CONFIRMBLOCKREQUESTBODY"]._serialized_start = 214
    _globals["_CONFIRMBLOCKREQUESTBODY"]._serialized_end = 287
    _globals["_CONFIRMBLOCKRESPONSE"]._serialized_start = 290
    _globals["_CONFIRMBLOCKRESPONSE"]._serialized_end = 420
    _globals["_CONFIRMBLOCKRESPONSEBODY"]._serialized_start = 422
    _globals["_CONFIRMBLOCKRESPONSEBODY"]._serialized_end = 547
    _globals["_STREAMPUTBLOCKREQUEST"]._serialized_start = 550
    _globals["_STREAMPUTBLOCKREQUEST"]._serialized_end = 764
    _globals["_STREAMPUTBLOCKREQUESTHEAD"]._serialized_start = 767
    _globals["_STREAMPUTBLOCKREQUESTHEAD"]._serialized_end = 907
    _globals["_STREAMPUTBLOCKREQUESTHEADBODY"]._serialized_start = 909
    _globals["_STREAMPUTBLOCKREQUESTHEADBODY"]._serialized_end = 988
    _globals["_STREAMPUTBLOCKREQUESTBODY"]._serialized_start = 990
    _globals["_STREAMPUTBLOCKREQUESTBODY"]._serialized_end = 1031
    _globals["_STREAMPUTBLOCKREQUESTTAIL"]._serialized_start = 1033
    _globals["_STREAMPUTBLOCKREQUESTTAIL"]._serialized_end = 1110
    _globals["_STREAMPUTBLOCKRESPONSE"]._serialized_start = 1113
    _globals["_STREAMPUTBLOCKRESPONSE"]._serialized_end = 1269
    _globals["_STREAMPUTBLOCKRESPONSEHEAD"]._serialized_start = 1272
    _globals["_STREAMPUTBLOCKRESPONSEHEAD"]._serialized_end = 1414
    _globals["_STREAMPUTBLOCKRESPONSEHEADBODY"]._serialized_start = 1417
    _globals["_STREAMPUTBLOCKRESPONSEHEADBODY"]._serialized_end = 1548
    _globals["_STREAMPUTBLOCKRESPONSETAIL"]._serialized_start = 1551
    _globals["_STREAMPUTBLOCKRESPONSETAIL"]._serialized_end = 1693
    _globals["_STREAMPUTBLOCKRESPONSETAILBODY"]._serialized_start = 1695
    _globals["_STREAMPUTBLOCKRESPONSETAILBODY"]._serialized_end = 1778
    _globals["_PUTBLOCKREQUEST"]._serialized_start = 1781
    _globals["_PUTBLOCKREQUEST"]._serialized_end = 1915
    _globals["_PUTBLOCKREQUESTBODY"]._serialized_start = 1917
    _globals["_PUTBLOCKREQUESTBODY"]._serialized_end = 1986
    _globals["_PUTBLOCKRESPONSE"]._serialized_start = 1988
    _globals["_PUTBLOCKRESPONSE"]._serialized_end = 2110
    _globals["_PUTBLOCKRESPONSEBODY"]._serialized_start = 2112
    _globals["_PUTBLOCKRESPONSEBODY"]._serialized_end = 2233
    _globals["_GETBLOCKREQUEST"]._serialized_start = 2235
    _globals["_GETBLOCKREQUEST"]._serialized_end = 2355
    _globals["_GETBLOCKREQUESTBODY"]._serialized_start = 2357
    _globals["_GETBLOCKREQUESTBODY"]._serialized_end = 2413
    _globals["_STREAMGETBLOCKREQUEST"]._serialized_start = 2416
    _globals["_STREAMGETBLOCKREQUEST"]._serialized_end = 2569
    _globals["_STREAMGETBLOCKREQUESTHEAD"]._serialized_start = 2572
    _globals["_STREAMGETBLOCKREQUESTHEAD"]._serialized_end = 2712
    _globals["_STREAMGETBLOCKREQUESTHEADBODY"]._serialized_start = 2714
    _globals["_STREAMGETBLOCKREQUESTHEADBODY"]._serialized_end = 2780
    _globals["_STREAMGETBLOCKREQUESTBODY"]._serialized_start = 2782
    _globals["_STREAMGETBLOCKREQUESTBODY"]._serialized_end = 2859
    _globals["_STREAMGETBLOCKRESPONSE"]._serialized_start = 2862
    _globals["_STREAMGETBLOCKRESPONSE"]._serialized_end = 3080
    _globals["_STREAMGETBLOCKRESPONSEHEAD"]._serialized_start = 3083
    _globals["_STREAMGETBLOCKRESPONSEHEAD"]._serialized_end = 3225
    _globals["_STREAMGETBLOCKRESPONSEHEADBODY"]._serialized_start = 3228
    _globals["_STREAMGETBLOCKRESPONSEHEADBODY"]._serialized_end = 3359
    _globals["_STREAMGETBLOCKRESPONSEBODY"]._serialized_start = 3361
    _globals["_STREAMGETBLOCKRESPONSEBODY"]._serialized_end = 3403
    _globals["_STREAMGETBLOCKRESPONSETAIL"]._serialized_start = 3406
    _globals["_STREAMGETBLOCKRESPONSETAIL"]._serialized_end = 3548
    _globals["_STREAMGETBLOCKRESPONSETAILBODY"]._serialized_start = 3550
    _globals["_STREAMGETBLOCKRESPONSETAILBODY"]._serialized_end = 3633
    _globals["_GETBLOCKRESPONSEBODY"]._serialized_start = 3635
    _globals["_GETBLOCKRESPONSEBODY"]._serialized_end = 3756
    _globals["_GETBLOCKRESPONSE"]._serialized_start = 3759
    _globals["_GETBLOCKRESPONSE"]._serialized_end = 3895
    _globals["_BLOCKMETADATA"]._serialized_start = 3898
    _globals["_BLOCKMETADATA"]._serialized_end = 4033
    _globals["_BLOCK"]._serialized_start = 4036
    _globals["_BLOCK"]._serialized_end = 4499
# @@protoc_insertion_point(module_scope)



from yeying.api.common import message_pb2 as _message_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class MakeFriendsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MakeFriendsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetFriendsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetFriendResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yeying.api.rag import memory_pb2 as yeying_dot_api_dot_rag_dot_memory__pb2

GRPC_GENERATED_VERSION = '1.73.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yeying/api/rag/memory_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class MemoryStub(object):
    """*
    记忆管理模块
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/yeying.api.rag.Memory/Create',
                request_serializer=yeying_dot_api_dot_rag_dot_memory__pb2.CreateMemoryRequest.SerializeToString,
                response_deserializer=yeying_dot_api_dot_rag_dot_memory__pb2.CreateMemoryResponse.FromString,
                _registered_method=True)
        self.Add = channel.unary_unary(
                '/yeying.api.rag.Memory/Add',
                request_serializer=yeying_dot_api_dot_rag_dot_memory__pb2.AddMemoryRequest.SerializeToString,
                response_deserializer=yeying_dot_api_dot_rag_dot_memory__pb2.AddMemoryResponse.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/yeying.api.rag.Memory/Delete',
                request_serializer=yeying_dot_api_dot_rag_dot_memory__pb2.DeleteMemoryRequest.SerializeToString,
                response_deserializer=yeying_dot_api_dot_rag_dot_memory__pb2.DeleteMemoryResponse.FromString,
                _registered_method=True)


class MemoryServicer(object):
    """*
    记忆管理模块
    """

    def Create(self, request, context):
        """创建记忆体
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Add(self, request, context):
        """添加内容到记忆体
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """删除记忆体中的内容
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MemoryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yeying_dot_api_dot_rag_dot_memory__pb2.CreateMemoryRequest.FromString,
                    response_serializer=yeying_dot_api_dot_rag_dot_memory__pb2.CreateMemoryResponse.SerializeToString,
            ),
            'Add': grpc.unary_unary_rpc_method_handler(
                    servicer.Add,
                    request_deserializer=yeying_dot_api_dot_rag_dot_memory__pb2.AddMemoryRequest.FromString,
                    response_serializer=yeying_dot_api_dot_rag_dot_memory__pb2.AddMemoryResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yeying_dot_api_dot_rag_dot_memory__pb2.DeleteMemoryRequest.FromString,
                    response_serializer=yeying_dot_api_dot_rag_dot_memory__pb2.DeleteMemoryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yeying.api.rag.Memory', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yeying.api.rag.Memory', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Memory(object):
    """*
    记忆管理模块
    """

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yeying.api.rag.Memory/Create',
            yeying_dot_api_dot_rag_dot_memory__pb2.CreateMemoryRequest.SerializeToString,
            yeying_dot_api_dot_rag_dot_memory__pb2.CreateMemoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Add(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yeying.api.rag.Memory/Add',
            yeying_dot_api_dot_rag_dot_memory__pb2.AddMemoryRequest.SerializeToString,
            yeying_dot_api_dot_rag_dot_memory__pb2.AddMemoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yeying.api.rag.Memory/Delete',
            yeying_dot_api_dot_rag_dot_memory__pb2.DeleteMemoryRequest.SerializeToString,
            yeying_dot_api_dot_rag_dot_memory__pb2.DeleteMemoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/knowledge/knowledge.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/knowledge/knowledge.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n$yeying/api/knowledge/knowledge.proto\x12\x12yeying.api.content\x1a\x1fyeying/api/common/message.proto\x1a\x1cyeying/api/common/code.proto"O\n\rSearchRequest\x12>\n\x0f\x61rticleMetadata\x18\x01 \x03(\x0b\x32%.yeying.api.content.KnowledgeMetadata"C\n\x0eSearchResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\xbf\x01\n\x11KnowledgeMetadata\x12\x34\n\x06\x66ormat\x18\x01 \x01(\x0e\x32$.yeying.api.common.DigitalFormatEnum\x12\x0c\n\x04hash\x18\x02 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12\x13\n\x0bpublishTime\x18\x05 \x01(\t\x12\x0f\n\x07keyword\x18\x06 \x01(\t\x12\x0f\n\x07summary\x18\x07 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x08 \x01(\t"C\n\x0e\x41ppendMetadata\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12\x12\n\nsubscriber\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t"K\n\rAppendRequest\x12:\n\x0e\x61ppendMetadata\x18\x01 \x03(\x0b\x32".yeying.api.content.AppendMetadata"C\n\x0e\x41ppendResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus*\x1a\n\x0b\x43ontentType\x12\x0b\n\x07\x41RTICLE\x10\x00\x32\xb1\x01\n\tKnowledge\x12Q\n\x06Search\x12!.yeying.api.content.SearchRequest\x1a".yeying.api.content.SearchResponse"\x00\x12Q\n\x06\x41ppend\x12!.yeying.api.content.AppendRequest\x1a".yeying.api.content.AppendResponse"\x00\x42\x14Z\x12yeying/api/contentb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.knowledge.knowledge_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\022yeying/api/content"
    _globals["_CONTENTTYPE"]._serialized_start = 682
    _globals["_CONTENTTYPE"]._serialized_end = 708
    _globals["_SEARCHREQUEST"]._serialized_start = 123
    _globals["_SEARCHREQUEST"]._serialized_end = 202
    _globals["_SEARCHRESPONSE"]._serialized_start = 204
    _globals["_SEARCHRESPONSE"]._serialized_end = 271
    _globals["_KNOWLEDGEMETADATA"]._serialized_start = 274
    _globals["_KNOWLEDGEMETADATA"]._serialized_end = 465
    _globals["_APPENDMETADATA"]._serialized_start = 467
    _globals["_APPENDMETADATA"]._serialized_end = 534
    _globals["_APPENDREQUEST"]._serialized_start = 536
    _globals["_APPENDREQUEST"]._serialized_end = 611
    _globals["_APPENDRESPONSE"]._serialized_start = 613
    _globals["_APPENDRESPONSE"]._serialized_end = 680
    _globals["_KNOWLEDGE"]._serialized_start = 711
    _globals["_KNOWLEDGE"]._serialized_end = 888
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/apps/zuoyepigai/imagecontent.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/apps/zuoyepigai/imagecontent.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n-yeying/api/apps/zuoyepigai/imagecontent.proto\x12\x1ayeying.api.apps.zuoyepigai*8\n\x14ImageContentTypeEnum\x12\x0c\n\x08QUESTION\x10\x00\x12\n\n\x06\x41NSWER\x10\x01\x12\x06\n\x02QA\x10\x02*\x80\x01\n\x0eTaskStatusEnum\x12\x0b\n\x07\x43REATED\x10\x00\x12\x10\n\x0cWAIT_MARKING\x10\x01\x12\x0b\n\x07MARKING\x10\x02\x12\x12\n\x0e\x46INISH_MARKING\x10\x03\x12\x0f\n\x0bWAIT_REVISE\x10\x04\x12\n\n\x06REVISE\x10\x05\x12\x11\n\rFINISH_REVISE\x10\x06\x42\x1cZ\x1ayeying/api/apps/zuoyepigaib\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.apps.zuoyepigai.imagecontent_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\032yeying/api/apps/zuoyepigai"
    _globals["_IMAGECONTENTTYPEENUM"]._serialized_start = 77
    _globals["_IMAGECONTENTTYPEENUM"]._serialized_end = 133
    _globals["_TASKSTATUSENUM"]._serialized_start = 136
    _globals["_TASKSTATUSENUM"]._serialized_end = 264
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/spider/topic.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/spider/topic.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1dyeying/api/spider/topic.proto\x12\x10yeying.api.topic\x1a\x1fyeying/api/common/message.proto\x1a\x1cyeying/api/common/code.proto"\x1e\n\rSearchRequest\x12\r\n\x05owner\x18\x01 \x01(\t"{\n\x0eSearchResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x36\n\rtopicMetadata\x18\x02 \x03(\x0b\x32\x1f.yeying.api.topic.TopicMetadata"1\n\x12UnsubscribeRequest\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x03(\t"H\n\x13UnsubscribeResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x9e\x01\n\rTopicMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x34\n\x06\x66ormat\x18\x02 \x03(\x0e\x32$.yeying.api.common.DigitalFormatEnum\x12\x12\n\nexpression\x18\x03 \x01(\t\x12\x35\n\x06status\x18\x04 \x01(\x0e\x32%.yeying.api.common.ContractStatusEnum"Y\n\x10SubscribeRequest\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x36\n\rtopicMetadata\x18\x02 \x03(\x0b\x32\x1f.yeying.api.topic.TopicMetadata"F\n\x11SubscribeResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus2\x8c\x02\n\x05Topic\x12M\n\x06Search\x12\x1f.yeying.api.topic.SearchRequest\x1a .yeying.api.topic.SearchResponse"\x00\x12V\n\tSubscribe\x12".yeying.api.topic.SubscribeRequest\x1a#.yeying.api.topic.SubscribeResponse"\x00\x12\\\n\x0bUnsubscribe\x12$.yeying.api.topic.UnsubscribeRequest\x1a%.yeying.api.topic.UnsubscribeResponse"\x00\x42\x12Z\x10yeying/api/topicb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.spider.topic_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\020yeying/api/topic"
    _globals["_SEARCHREQUEST"]._serialized_start = 114
    _globals["_SEARCHREQUEST"]._serialized_end = 144
    _globals["_SEARCHRESPONSE"]._serialized_start = 146
    _globals["_SEARCHRESPONSE"]._serialized_end = 269
    _globals["_UNSUBSCRIBEREQUEST"]._serialized_start = 271
    _globals["_UNSUBSCRIBEREQUEST"]._serialized_end = 320
    _globals["_UNSUBSCRIBERESPONSE"]._serialized_start = 322
    _globals["_UNSUBSCRIBERESPONSE"]._serialized_end = 394
    _globals["_TOPICMETADATA"]._serialized_start = 397
    _globals["_TOPICMETADATA"]._serialized_end = 555
    _globals["_SUBSCRIBEREQUEST"]._serialized_start = 557
    _globals["_SUBSCRIBEREQUEST"]._serialized_end = 646
    _globals["_SUBSCRIBERESPONSE"]._serialized_start = 648
    _globals["_SUBSCRIBERESPONSE"]._serialized_end = 718
    _globals["_TOPIC"]._serialized_start = 721
    _globals["_TOPIC"]._serialized_end = 989
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/identity/identity.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/identity/identity.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n"yeying/api/identity/identity.proto\x12\x13yeying.api.identity\x1a\x1fyeying/api/common/message.proto\x1a\x1cyeying/api/common/code.proto"y\n\x0e\x44\x65positRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.identity.DepositRequestBody"6\n\x12\x44\x65positRequestBody\x12\x0e\n\x06\x63ipher\x18\x01 \x01(\t\x12\x10\n\x08protocol\x18\x02 \x01(\t"{\n\x0f\x44\x65positResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.identity.DepositResponseBody"H\n\x13\x44\x65positResponseBody\x12\x31\n\x06status\x18\x02 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"C\n\x0fRetrieveRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"D\n\x10RetrieveResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"@\n\x0cShareRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"A\n\rShareResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"u\n\x0cQueryRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x33\n\x04\x62ody\x18\x02 \x01(\x0b\x32%.yeying.api.identity.QueryRequestBody"K\n\x10QueryRequestBody\x12\x37\n\x0bserviceCode\x18\x01 \x01(\x0e\x32".yeying.api.common.ServiceCodeEnum"w\n\rQueryResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32&.yeying.api.identity.QueryResponseBody"h\n\x11QueryResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x0e\n\x06\x63ipher\x18\x02 \x01(\t\x12\x10\n\x08protocol\x18\x03 \x01(\t"w\n\rCancelRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32&.yeying.api.identity.CancelRequestBody" \n\x11\x43\x61ncelRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t"y\n\x0e\x43\x61ncelResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.identity.CancelResponseBody"G\n\x12\x43\x61ncelResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus2\xb6\x03\n\x08Identity\x12V\n\x07\x44\x65posit\x12#.yeying.api.identity.DepositRequest\x1a$.yeying.api.identity.DepositResponse"\x00\x12Y\n\x08Retrieve\x12$.yeying.api.identity.RetrieveRequest\x1a%.yeying.api.identity.RetrieveResponse"\x00\x12P\n\x05Query\x12!.yeying.api.identity.QueryRequest\x1a".yeying.api.identity.QueryResponse"\x00\x12P\n\x05Share\x12!.yeying.api.identity.ShareRequest\x1a".yeying.api.identity.ShareResponse"\x00\x12S\n\x06\x43\x61ncel\x12".yeying.api.identity.CancelRequest\x1a#.yeying.api.identity.CancelResponse"\x00\x42\x15Z\x13yeying/api/identityb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.identity.identity_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\023yeying/api/identity"
    _globals["_DEPOSITREQUEST"]._serialized_start = 122
    _globals["_DEPOSITREQUEST"]._serialized_end = 243
    _globals["_DEPOSITREQUESTBODY"]._serialized_start = 245
    _globals["_DEPOSITREQUESTBODY"]._serialized_end = 299
    _globals["_DEPOSITRESPONSE"]._serialized_start = 301
    _globals["_DEPOSITRESPONSE"]._serialized_end = 424
    _globals["_DEPOSITRESPONSEBODY"]._serialized_start = 426
    _globals["_DEPOSITRESPONSEBODY"]._serialized_end = 498
    _globals["_RETRIEVEREQUEST"]._serialized_start = 500
    _globals["_RETRIEVEREQUEST"]._serialized_end = 567
    _globals["_RETRIEVERESPONSE"]._serialized_start = 569
    _globals["_RETRIEVERESPONSE"]._serialized_end = 637
    _globals["_SHAREREQUEST"]._serialized_start = 639
    _globals["_SHAREREQUEST"]._serialized_end = 703
    _globals["_SHARERESPONSE"]._serialized_start = 705
    _globals["_SHARERESPONSE"]._serialized_end = 770
    _globals["_QUERYREQUEST"]._serialized_start = 772
    _globals["_QUERYREQUEST"]._serialized_end = 889
    _globals["_QUERYREQUESTBODY"]._serialized_start = 891
    _globals["_QUERYREQUESTBODY"]._serialized_end = 966
    _globals["_QUERYRESPONSE"]._serialized_start = 968
    _globals["_QUERYRESPONSE"]._serialized_end = 1087
    _globals["_QUERYRESPONSEBODY"]._serialized_start = 1089
    _globals["_QUERYRESPONSEBODY"]._serialized_end = 1193
    _globals["_CANCELREQUEST"]._serialized_start = 1195
    _globals["_CANCELREQUEST"]._serialized_end = 1314
    _globals["_CANCELREQUESTBODY"]._serialized_start = 1316
    _globals["_CANCELREQUESTBODY"]._serialized_end = 1348
    _globals["_CANCELRESPONSE"]._serialized_start = 1350
    _globals["_CANCELRESPONSE"]._serialized_end = 1471
    _globals["_CANCELRESPONSEBODY"]._serialized_start = 1473
    _globals["_CANCELRESPONSEBODY"]._serialized_end = 1544
    _globals["_IDENTITY"]._serialized_start = 1547
    _globals["_IDENTITY"]._serialized_end = 1985
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yeying.api.apps.zuoyepigai import assignment_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2

GRPC_GENERATED_VERSION = "1.68.1"
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower

    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f"The grpc package installed is at version {GRPC_VERSION},"
        + f" but the generated code in yeying/api/apps/zuoyepigai/assignment_pb2_grpc.py depends on"
        + f" grpcio>={GRPC_GENERATED_VERSION}."
        + f" Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}"
        + f" or downgrade your generated code using grpcio-tools<={GRPC_VERSION}."
    )


class AssignmentStub(object):
    """*
    作业管理
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Upload = channel.unary_unary(
            "/yeying.api.apps.zuoyepigai.Assignment/Upload",
            request_serializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentUploadRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentUploadResponse.FromString,
            _registered_method=True,
        )
        self.BigModelGenerate = channel.unary_unary(
            "/yeying.api.apps.zuoyepigai.Assignment/BigModelGenerate",
            request_serializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentBigModelRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentBigModelResponse.FromString,
            _registered_method=True,
        )
        self.ArtificialGenerate = channel.unary_unary(
            "/yeying.api.apps.zuoyepigai.Assignment/ArtificialGenerate",
            request_serializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentArtificialRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentArtificialResponse.FromString,
            _registered_method=True,
        )
        self.StudentAction = channel.unary_unary(
            "/yeying.api.apps.zuoyepigai.Assignment/StudentAction",
            request_serializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.StudentActionRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.StudentActionResponse.FromString,
            _registered_method=True,
        )
        self.Correction = channel.unary_unary(
            "/yeying.api.apps.zuoyepigai.Assignment/Correction",
            request_serializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentCorrectionRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentCorrectionResponse.FromString,
            _registered_method=True,
        )


class AssignmentServicer(object):
    """*
    作业管理
    """

    def Upload(self, request, context):
        """老师上传作业, 图片题目识别 (OCR)，将图片上的题目转换为文字信息存储到 DB
        对应 DB 表：
        zuoyepigai.test_paper，试卷
        zuoyepigai.question_collection，题目
        zuoyepigai.answer_collection，答案
        zuoyepigai.warehouse，资产仓库
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def BigModelGenerate(self, request, context):
        """大模型生成答案 (做题)，从题库中获取题目，调用解题的大模型生成对应题目的答案，并保存到 DB
        对应 DB 表：
        zuoyepigai.test_paper，试卷
        zuoyepigai.question_collection，题目
        zuoyepigai.answer_collection，答案
        zuoyepigai.warehouse，资产仓库
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ArtificialGenerate(self, request, context):
        """人工生成答案，人工做题，拍照上传生成题库答案"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StudentAction(self, request, context):
        """学生加减，该任务对那些学生可见和不可见，老师可以自己来调整"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Correction(self, request, context):
        """作业批改，学生做完试卷后提交给老师，老师统一拍照上传批改处理"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_AssignmentServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Upload": grpc.unary_unary_rpc_method_handler(
            servicer.Upload,
            request_deserializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentUploadRequest.FromString,
            response_serializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentUploadResponse.SerializeToString,
        ),
        "BigModelGenerate": grpc.unary_unary_rpc_method_handler(
            servicer.BigModelGenerate,
            request_deserializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentBigModelRequest.FromString,
            response_serializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentBigModelResponse.SerializeToString,
        ),
        "ArtificialGenerate": grpc.unary_unary_rpc_method_handler(
            servicer.ArtificialGenerate,
            request_deserializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentArtificialRequest.FromString,
            response_serializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentArtificialResponse.SerializeToString,
        ),
        "StudentAction": grpc.unary_unary_rpc_method_handler(
            servicer.StudentAction,
            request_deserializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.StudentActionRequest.FromString,
            response_serializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.StudentActionResponse.SerializeToString,
        ),
        "Correction": grpc.unary_unary_rpc_method_handler(
            servicer.Correction,
            request_deserializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentCorrectionRequest.FromString,
            response_serializer=yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentCorrectionResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("yeying.api.apps.zuoyepigai.Assignment", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("yeying.api.apps.zuoyepigai.Assignment", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class Assignment(object):
    """*
    作业管理
    """

    @staticmethod
    def Upload(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.apps.zuoyepigai.Assignment/Upload",
            yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentUploadRequest.SerializeToString,
            yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentUploadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def BigModelGenerate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.apps.zuoyepigai.Assignment/BigModelGenerate",
            yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentBigModelRequest.SerializeToString,
            yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentBigModelResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def ArtificialGenerate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.apps.zuoyepigai.Assignment/ArtificialGenerate",
            yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentArtificialRequest.SerializeToString,
            yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentArtificialResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def StudentAction(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.apps.zuoyepigai.Assignment/StudentAction",
            yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.StudentActionRequest.SerializeToString,
            yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.StudentActionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Correction(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.apps.zuoyepigai.Assignment/Correction",
            yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentCorrectionRequest.SerializeToString,
            yeying_dot_api_dot_apps_dot_zuoyepigai_dot_assignment__pb2.AssignmentCorrectionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/audit/audit.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/audit/audit.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2
from yeying.api.common import model_pb2 as yeying_dot_api_dot_common_dot_model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1cyeying/api/audit/audit.proto\x12\x10yeying.api.audit\x1a\x1fyeying/api/common/message.proto\x1a\x1cyeying/api/common/code.proto\x1a\x1dyeying/api/common/model.proto"\xe5\x01\n\x0b\x41uditStatus\x12\x32\n\x07pending\x18\x01 \x01(\x0b\x32\x1f.yeying.api.audit.PendingStatusH\x00\x12\x34\n\x08\x63\x61nceled\x18\x02 \x01(\x0b\x32 .yeying.api.audit.CanceledStatusH\x00\x12\x30\n\x06passed\x18\x03 \x01(\x0b\x32\x1e.yeying.api.audit.PassedStatusH\x00\x12\x30\n\x06reject\x18\x04 \x01(\x0b\x32\x1e.yeying.api.audit.RejectStatusH\x00\x42\x08\n\x06status"\x1d\n\rPendingStatus\x12\x0c\n\x04text\x18\x02 \x01(\t"\x1e\n\x0e\x43\x61nceledStatus\x12\x0c\n\x04text\x18\x02 \x01(\t"\x1c\n\x0cPassedStatus\x12\x0c\n\x04text\x18\x02 \x01(\t"\x1c\n\x0cRejectStatus\x12\x0c\n\x04text\x18\x02 \x01(\t"t\n\rCreateRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x31\n\x04\x62ody\x18\x02 \x01(\x0b\x32#.yeying.api.audit.CreateRequestBody"B\n\x11\x43reateRequestBody\x12-\n\x04meta\x18\x01 \x01(\x0b\x32\x1f.yeying.api.audit.AuditMetadata"v\n\x0e\x43reateResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x32\n\x04\x62ody\x18\x02 \x01(\x0b\x32$.yeying.api.audit.CreateResponseBody"v\n\x12\x43reateResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12-\n\x04meta\x18\x02 \x01(\x0b\x32\x1f.yeying.api.audit.AuditMetadata"t\n\rDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x31\n\x04\x62ody\x18\x02 \x01(\x0b\x32#.yeying.api.audit.DetailRequestBody" \n\x11\x44\x65tailRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"v\n\x0e\x44\x65tailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x32\n\x04\x62ody\x18\x02 \x01(\x0b\x32$.yeying.api.audit.DetailResponseBody"v\n\x12\x44\x65tailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12-\n\x04meta\x18\x02 \x01(\x0b\x32\x1f.yeying.api.audit.AuditMetadata"t\n\rCancelRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x31\n\x04\x62ody\x18\x02 \x01(\x0b\x32#.yeying.api.audit.CancelRequestBody" \n\x11\x43\x61ncelRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"v\n\x0e\x43\x61ncelResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x32\n\x04\x62ody\x18\x02 \x01(\x0b\x32$.yeying.api.audit.CancelResponseBody"v\n\x12\x43\x61ncelResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12-\n\x04meta\x18\x02 \x01(\x0b\x32\x1f.yeying.api.audit.AuditMetadata"t\n\rUnbindRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x31\n\x04\x62ody\x18\x02 \x01(\x0b\x32#.yeying.api.audit.UnbindRequestBody" \n\x11UnbindRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"v\n\x0eUnbindResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x32\n\x04\x62ody\x18\x02 \x01(\x0b\x32$.yeying.api.audit.UnbindResponseBody"G\n\x12UnbindResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"r\n\x0c\x41uditRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x30\n\x04\x62ody\x18\x02 \x01(\x0b\x32".yeying.api.audit.AuditRequestBody"N\n\x10\x41uditRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12-\n\x06status\x18\x02 \x01(\x0b\x32\x1d.yeying.api.audit.AuditStatus"t\n\rAuditResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x31\n\x04\x62ody\x18\x02 \x01(\x0b\x32#.yeying.api.audit.AuditResponseBody"u\n\x11\x41uditResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12-\n\x04meta\x18\x02 \x01(\x0b\x32\x1f.yeying.api.audit.AuditMetadata"\x86\x01\n\x16\x43reateAuditListRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.audit.CreateAuditListRequestBody"\x85\x01\n\x1a\x43reateAuditListRequestBody\x12\x39\n\tcondition\x18\x01 \x01(\x0b\x32&.yeying.api.audit.AuditSearchCondition\x12,\n\x04page\x18\x02 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage"\x88\x01\n\x17\x43reateAuditListResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.audit.CreateAuditListResponseBody"\xb0\x01\n\x1b\x43reateAuditListResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12/\n\x06\x61udits\x18\x02 \x03(\x0b\x32\x1f.yeying.api.audit.AuditMetadata\x12-\n\x04page\x18\x03 \x01(\x0b\x32\x1f.yeying.api.common.ResponsePage"z\n\x10\x41uditListRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32&.yeying.api.audit.AuditListRequestBody"\x7f\n\x14\x41uditListRequestBody\x12\x39\n\tcondition\x18\x01 \x01(\x0b\x32&.yeying.api.audit.AuditSearchCondition\x12,\n\x04page\x18\x02 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage"|\n\x11\x41uditListResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.audit.AuditListResponseBody"\xaa\x01\n\x15\x41uditListResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12/\n\x06\x61udits\x18\x02 \x03(\x0b\x32\x1f.yeying.api.audit.AuditMetadata\x12-\n\x04page\x18\x03 \x01(\x0b\x32\x1f.yeying.api.common.ResponsePage"\x9e\x01\n\x14\x41uditSearchCondition\x12\x11\n\tsourceDid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tstartTime\x18\x03 \x01(\t\x12\x0f\n\x07\x65ndTime\x18\x04 \x01(\t\x12.\n\x04type\x18\x05 \x01(\x0e\x32 .yeying.api.common.AuditTypeEnum\x12\x11\n\ttargetDid\x18\x06 \x01(\t"\x90\x02\n\rAuditMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x0f\n\x07\x61ppName\x18\x02 \x01(\t\x12\x11\n\tsourceDid\x18\x03 \x01(\t\x12\x12\n\nsourceName\x18\x04 \x01(\t\x12\x11\n\ttargetDid\x18\x05 \x01(\t\x12\x12\n\ntargetName\x18\x06 \x01(\t\x12\x0e\n\x06reason\x18\x07 \x01(\t\x12-\n\x06status\x18\x08 \x01(\x0b\x32\x1d.yeying.api.audit.AuditStatus\x12\x11\n\tcreatedAt\x18\t \x01(\t\x12\x11\n\tupdatedAt\x18\n \x01(\t\x12.\n\x04type\x18\x0b \x01(\x0e\x32 .yeying.api.common.AuditTypeEnum2\xcc\x04\n\x05\x41udit\x12M\n\x06\x43reate\x12\x1f.yeying.api.audit.CreateRequest\x1a .yeying.api.audit.CreateResponse"\x00\x12M\n\x06\x44\x65tail\x12\x1f.yeying.api.audit.DetailRequest\x1a .yeying.api.audit.DetailResponse"\x00\x12M\n\x06\x43\x61ncel\x12\x1f.yeying.api.audit.CancelRequest\x1a .yeying.api.audit.CancelResponse"\x00\x12M\n\x06Unbind\x12\x1f.yeying.api.audit.UnbindRequest\x1a .yeying.api.audit.UnbindResponse"\x00\x12J\n\x05\x41udit\x12\x1e.yeying.api.audit.AuditRequest\x1a\x1f.yeying.api.audit.AuditResponse"\x00\x12\x63\n\nCreateList\x12(.yeying.api.audit.CreateAuditListRequest\x1a).yeying.api.audit.CreateAuditListResponse"\x00\x12V\n\tAuditList\x12".yeying.api.audit.AuditListRequest\x1a#.yeying.api.audit.AuditListResponse"\x00\x42\x12Z\x10yeying/api/auditb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.audit.audit_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\020yeying/api/audit"
    _globals["_AUDITSTATUS"]._serialized_start = 145
    _globals["_AUDITSTATUS"]._serialized_end = 374
    _globals["_PENDINGSTATUS"]._serialized_start = 376
    _globals["_PENDINGSTATUS"]._serialized_end = 405
    _globals["_CANCELEDSTATUS"]._serialized_start = 407
    _globals["_CANCELEDSTATUS"]._serialized_end = 437
    _globals["_PASSEDSTATUS"]._serialized_start = 439
    _globals["_PASSEDSTATUS"]._serialized_end = 467
    _globals["_REJECTSTATUS"]._serialized_start = 469
    _globals["_REJECTSTATUS"]._serialized_end = 497
    _globals["_CREATEREQUEST"]._serialized_start = 499
    _globals["_CREATEREQUEST"]._serialized_end = 615
    _globals["_CREATEREQUESTBODY"]._serialized_start = 617
    _globals["_CREATEREQUESTBODY"]._serialized_end = 683
    _globals["_CREATERESPONSE"]._serialized_start = 685
    _globals["_CREATERESPONSE"]._serialized_end = 803
    _globals["_CREATERESPONSEBODY"]._serialized_start = 805
    _globals["_CREATERESPONSEBODY"]._serialized_end = 923
    _globals["_DETAILREQUEST"]._serialized_start = 925
    _globals["_DETAILREQUEST"]._serialized_end = 1041
    _globals["_DETAILREQUESTBODY"]._serialized_start = 1043
    _globals["_DETAILREQUESTBODY"]._serialized_end = 1075
    _globals["_DETAILRESPONSE"]._serialized_start = 1077
    _globals["_DETAILRESPONSE"]._serialized_end = 1195
    _globals["_DETAILRESPONSEBODY"]._serialized_start = 1197
    _globals["_DETAILRESPONSEBODY"]._serialized_end = 1315
    _globals["_CANCELREQUEST"]._serialized_start = 1317
    _globals["_CANCELREQUEST"]._serialized_end = 1433
    _globals["_CANCELREQUESTBODY"]._serialized_start = 1435
    _globals["_CANCELREQUESTBODY"]._serialized_end = 1467
    _globals["_CANCELRESPONSE"]._serialized_start = 1469
    _globals["_CANCELRESPONSE"]._serialized_end = 1587
    _globals["_CANCELRESPONSEBODY"]._serialized_start = 1589
    _globals["_CANCELRESPONSEBODY"]._serialized_end = 1707
    _globals["_UNBINDREQUEST"]._serialized_start = 1709
    _globals["_UNBINDREQUEST"]._serialized_end = 1825
    _globals["_UNBINDREQUESTBODY"]._serialized_start = 1827
    _globals["_UNBINDREQUESTBODY"]._serialized_end = 1859
    _globals["_UNBINDRESPONSE"]._serialized_start = 1861
    _globals["_UNBINDRESPONSE"]._serialized_end = 1979
    _globals["_UNBINDRESPONSEBODY"]._serialized_start = 1981
    _globals["_UNBINDRESPONSEBODY"]._serialized_end = 2052
    _globals["_AUDITREQUEST"]._serialized_start = 2054
    _globals["_AUDITREQUEST"]._serialized_end = 2168
    _globals["_AUDITREQUESTBODY"]._serialized_start = 2170
    _globals["_AUDITREQUESTBODY"]._serialized_end = 2248
    _globals["_AUDITRESPONSE"]._serialized_start = 2250
    _globals["_AUDITRESPONSE"]._serialized_end = 2366
    _globals["_AUDITRESPONSEBODY"]._serialized_start = 2368
    _globals["_AUDITRESPONSEBODY"]._serialized_end = 2485
    _globals["_CREATEAUDITLISTREQUEST"]._serialized_start = 2488
    _globals["_CREATEAUDITLISTREQUEST"]._serialized_end = 2622
    _globals["_CREATEAUDITLISTREQUESTBODY"]._serialized_start = 2625
    _globals["_CREATEAUDITLISTREQUESTBODY"]._serialized_end = 2758
    _globals["_CREATEAUDITLISTRESPONSE"]._serialized_start = 2761
    _globals["_CREATEAUDITLISTRESPONSE"]._serialized_end = 2897
    _globals["_CREATEAUDITLISTRESPONSEBODY"]._serialized_start = 2900
    _globals["_CREATEAUDITLISTRESPONSEBODY"]._serialized_end = 3076
    _globals["_AUDITLISTREQUEST"]._serialized_start = 3078
    _globals["_AUDITLISTREQUEST"]._serialized_end = 3200
    _globals["_AUDITLISTREQUESTBODY"]._serialized_start = 3202
    _globals["_AUDITLISTREQUESTBODY"]._serialized_end = 3329
    _globals["_AUDITLISTRESPONSE"]._serialized_start = 3331
    _globals["_AUDITLISTRESPONSE"]._serialized_end = 3455
    _globals["_AUDITLISTRESPONSEBODY"]._serialized_start = 3458
    _globals["_AUDITLISTRESPONSEBODY"]._serialized_end = 3628
    _globals["_AUDITSEARCHCONDITION"]._serialized_start = 3631
    _globals["_AUDITSEARCHCONDITION"]._serialized_end = 3789
    _globals["_AUDITMETADATA"]._serialized_start = 3792
    _globals["_AUDITMETADATA"]._serialized_end = 4064
    _globals["_AUDIT"]._serialized_start = 4067
    _globals["_AUDIT"]._serialized_end = 4655
# @@protoc_insertion_point(module_scope)



from yeying.api.common import message_pb2 as _message_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from yeying.api.apps.zuoyepigai import meta_pb2 as _meta_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class ArchiveListRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ArchiveListRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ArchiveListRequestBody, _Mapping]] = ...,
    ) -> None: ...

class ArchiveListRequestBody(_message.Message):
    __slots__ = ("teacherDid", "name", "pageIndex", "pageSize")
    TEACHERDID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PAGEINDEX_FIELD_NUMBER: _ClassVar[int]
    PAGESIZE_FIELD_NUMBER: _ClassVar[int]
    teacherDid: str
    name: str
    pageIndex: _wrappers_pb2.Int32Value
    pageSize: _wrappers_pb2.Int32Value
    def __init__(
        self,
        teacherDid: _Optional[str] = ...,
        name: _Optional[str] = ...,
        pageIndex: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ...,
        pageSize: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ...,
    ) -> None: ...

class ArchiveListResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ArchiveListResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ArchiveListResponseBody, _Mapping]] = ...,
    ) -> None: ...

class ArchiveListResponseBody(_message.Message):
    __slots__ = ("status", "list", "total")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    LIST_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    list: _containers.RepeatedCompositeFieldContainer[_meta_pb2.ArchiveMetadata]
    total: int
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        list: _Optional[_Iterable[_Union[_meta_pb2.ArchiveMetadata, _Mapping]]] = ...,
        total: _Optional[int] = ...,
    ) -> None: ...

class ArchiveDetailRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ArchiveDetailRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ArchiveDetailRequestBody, _Mapping]] = ...,
    ) -> None: ...

class ArchiveDetailRequestBody(_message.Message):
    __slots__ = ("uid",)
    UID_FIELD_NUMBER: _ClassVar[int]
    uid: str
    def __init__(self, uid: _Optional[str] = ...) -> None: ...

class ArchiveDetailResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ArchiveDetailResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ArchiveDetailResponseBody, _Mapping]] = ...,
    ) -> None: ...

class ArchiveDetailResponseBody(_message.Message):
    __slots__ = ("status", "meta")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: _meta_pb2.ArchiveMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Union[_meta_pb2.ArchiveMetadata, _Mapping]] = ...,
    ) -> None: ...

class ArchiveDetailStudentRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ArchiveDetailStudentRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ArchiveDetailStudentRequestBody, _Mapping]] = ...,
    ) -> None: ...

class ArchiveDetailStudentRequestBody(_message.Message):
    __slots__ = ("studentDid",)
    STUDENTDID_FIELD_NUMBER: _ClassVar[int]
    studentDid: str
    def __init__(self, studentDid: _Optional[str] = ...) -> None: ...

class ArchiveDetailStudentResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ArchiveDetailStudentResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ArchiveDetailStudentResponseBody, _Mapping]] = ...,
    ) -> None: ...

class ArchiveDetailStudentResponseBody(_message.Message):
    __slots__ = ("status", "meta")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: _meta_pb2.ArchiveMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Union[_meta_pb2.ArchiveMetadata, _Mapping]] = ...,
    ) -> None: ...

class ArchiveAddRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ArchiveAddRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ArchiveAddRequestBody, _Mapping]] = ...,
    ) -> None: ...

class ArchiveAddRequestBody(_message.Message):
    __slots__ = ("meta",)
    META_FIELD_NUMBER: _ClassVar[int]
    meta: _meta_pb2.ArchiveMetadata
    def __init__(self, meta: _Optional[_Union[_meta_pb2.ArchiveMetadata, _Mapping]] = ...) -> None: ...

class ArchiveAddResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ArchiveAddResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ArchiveAddResponseBody, _Mapping]] = ...,
    ) -> None: ...

class ArchiveAddResponseBody(_message.Message):
    __slots__ = ("status", "meta")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: _meta_pb2.ArchiveMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Union[_meta_pb2.ArchiveMetadata, _Mapping]] = ...,
    ) -> None: ...

class ArchiveDeleteRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ArchiveDeleteRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ArchiveDeleteRequestBody, _Mapping]] = ...,
    ) -> None: ...

class ArchiveDeleteRequestBody(_message.Message):
    __slots__ = ("uid",)
    UID_FIELD_NUMBER: _ClassVar[int]
    uid: str
    def __init__(self, uid: _Optional[str] = ...) -> None: ...

class ArchiveDeleteResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ArchiveDeleteResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ArchiveDeleteResponseBody, _Mapping]] = ...,
    ) -> None: ...

class ArchiveDeleteResponseBody(_message.Message):
    __slots__ = ("status", "meta")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: _meta_pb2.ArchiveMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Union[_meta_pb2.ArchiveMetadata, _Mapping]] = ...,
    ) -> None: ...

class ArchiveUpdateRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ArchiveUpdateRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ArchiveUpdateRequestBody, _Mapping]] = ...,
    ) -> None: ...

class ArchiveUpdateRequestBody(_message.Message):
    __slots__ = ("meta",)
    META_FIELD_NUMBER: _ClassVar[int]
    meta: _meta_pb2.ArchiveMetadata
    def __init__(self, meta: _Optional[_Union[_meta_pb2.ArchiveMetadata, _Mapping]] = ...) -> None: ...

class ArchiveUpdateResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ArchiveUpdateResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ArchiveUpdateResponseBody, _Mapping]] = ...,
    ) -> None: ...

class ArchiveUpdateResponseBody(_message.Message):
    __slots__ = ("status", "meta")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: _meta_pb2.ArchiveMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Union[_meta_pb2.ArchiveMetadata, _Mapping]] = ...,
    ) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/apps/zuoyepigai/warehouse.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/apps/zuoyepigai/warehouse.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yeying.api.apps.zuoyepigai import meta_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n*yeying/api/apps/zuoyepigai/warehouse.proto\x12\x1ayeying.api.apps.zuoyepigai\x1a\x1fyeying/api/common/message.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a%yeying/api/apps/zuoyepigai/meta.proto"\x90\x01\n\x16\x44\x65tailWarehouseRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x44\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x36.yeying.api.apps.zuoyepigai.DetailWarehouseRequestBody")\n\x1a\x44\x65tailWarehouseRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x92\x01\n\x17\x44\x65tailWarehouseResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x45\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x37.yeying.api.apps.zuoyepigai.DetailWarehouseResponseBody"\x8d\x01\n\x1b\x44\x65tailWarehouseResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12;\n\x04meta\x18\x02 \x01(\x0b\x32-.yeying.api.apps.zuoyepigai.WarehouseMetadata"\x8a\x01\n\x13\x41\x64\x64WarehouseRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.apps.zuoyepigai.AddWarehouseRequestBody"V\n\x17\x41\x64\x64WarehouseRequestBody\x12;\n\x04meta\x18\x01 \x01(\x0b\x32-.yeying.api.apps.zuoyepigai.WarehouseMetadata"\x8c\x01\n\x14\x41\x64\x64WarehouseResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.AddWarehouseResponseBody"\x8a\x01\n\x18\x41\x64\x64WarehouseResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12;\n\x04meta\x18\x02 \x01(\x0b\x32-.yeying.api.apps.zuoyepigai.WarehouseMetadata"\x8c\x01\n\x14ListWarehouseRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.ListWarehouseRequestBody"\x97\x01\n\x18ListWarehouseRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x0f\n\x07taskUid\x18\x02 \x01(\t\x12.\n\tpageIndex\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12-\n\x08pageSize\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value"\x8e\x01\n\x15ListWarehouseResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.ListWarehouseResponseBody"\x9a\x01\n\x19ListWarehouseResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12;\n\x04list\x18\x02 \x03(\x0b\x32-.yeying.api.apps.zuoyepigai.WarehouseMetadata\x12\r\n\x05total\x18\x03 \x01(\x04\x32\xdb\x02\n\tWarehouse\x12j\n\x03\x41\x64\x64\x12/.yeying.api.apps.zuoyepigai.AddWarehouseRequest\x1a\x30.yeying.api.apps.zuoyepigai.AddWarehouseResponse"\x00\x12m\n\x04List\x12\x30.yeying.api.apps.zuoyepigai.ListWarehouseRequest\x1a\x31.yeying.api.apps.zuoyepigai.ListWarehouseResponse"\x00\x12s\n\x06\x44\x65tail\x12\x32.yeying.api.apps.zuoyepigai.DetailWarehouseRequest\x1a\x33.yeying.api.apps.zuoyepigai.DetailWarehouseResponse"\x00\x42\x1cZ\x1ayeying/api/apps/zuoyepigaib\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.apps.zuoyepigai.warehouse_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\032yeying/api/apps/zuoyepigai"
    _globals["_DETAILWAREHOUSEREQUEST"]._serialized_start = 179
    _globals["_DETAILWAREHOUSEREQUEST"]._serialized_end = 323
    _globals["_DETAILWAREHOUSEREQUESTBODY"]._serialized_start = 325
    _globals["_DETAILWAREHOUSEREQUESTBODY"]._serialized_end = 366
    _globals["_DETAILWAREHOUSERESPONSE"]._serialized_start = 369
    _globals["_DETAILWAREHOUSERESPONSE"]._serialized_end = 515
    _globals["_DETAILWAREHOUSERESPONSEBODY"]._serialized_start = 518
    _globals["_DETAILWAREHOUSERESPONSEBODY"]._serialized_end = 659
    _globals["_ADDWAREHOUSEREQUEST"]._serialized_start = 662
    _globals["_ADDWAREHOUSEREQUEST"]._serialized_end = 800
    _globals["_ADDWAREHOUSEREQUESTBODY"]._serialized_start = 802
    _globals["_ADDWAREHOUSEREQUESTBODY"]._serialized_end = 888
    _globals["_ADDWAREHOUSERESPONSE"]._serialized_start = 891
    _globals["_ADDWAREHOUSERESPONSE"]._serialized_end = 1031
    _globals["_ADDWAREHOUSERESPONSEBODY"]._serialized_start = 1034
    _globals["_ADDWAREHOUSERESPONSEBODY"]._serialized_end = 1172
    _globals["_LISTWAREHOUSEREQUEST"]._serialized_start = 1175
    _globals["_LISTWAREHOUSEREQUEST"]._serialized_end = 1315
    _globals["_LISTWAREHOUSEREQUESTBODY"]._serialized_start = 1318
    _globals["_LISTWAREHOUSEREQUESTBODY"]._serialized_end = 1469
    _globals["_LISTWAREHOUSERESPONSE"]._serialized_start = 1472
    _globals["_LISTWAREHOUSERESPONSE"]._serialized_end = 1614
    _globals["_LISTWAREHOUSERESPONSEBODY"]._serialized_start = 1617
    _globals["_LISTWAREHOUSERESPONSEBODY"]._serialized_end = 1771
    _globals["_WAREHOUSE"]._serialized_start = 1774
    _globals["_WAREHOUSE"]._serialized_end = 2121
# @@protoc_insertion_point(module_scope)



# Generated by protobuf_init. Do not edit manually.
from .social_pb2 import MakeFriendsRequest
from .social_pb2 import MakeFriendsResponse
from .social_pb2 import GetFriendsRequest
from .social_pb2 import GetFriendResponse
from .social_pb2_grpc import SocialServicer
from .social_pb2_grpc import SocialStub
from .social_pb2_grpc import add_SocialServicer_to_server
from .social_pb2_grpc import Social



from yeying.api.common import message_pb2 as _message_pb2
from yeying.api.common import code_pb2 as _code_pb2
from yeying.api.common import model_pb2 as _model_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class CreateServiceRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CreateServiceRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CreateServiceRequestBody, _Mapping]] = ...,
    ) -> None: ...

class CreateServiceRequestBody(_message.Message):
    __slots__ = ("service",)
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    service: _model_pb2.ServiceMetadata
    def __init__(self, service: _Optional[_Union[_model_pb2.ServiceMetadata, _Mapping]] = ...) -> None: ...

class CreateServiceResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CreateServiceResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CreateServiceResponseBody, _Mapping]] = ...,
    ) -> None: ...

class CreateServiceResponseBody(_message.Message):
    __slots__ = ("status", "service")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    service: _model_pb2.ServiceMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        service: _Optional[_Union[_model_pb2.ServiceMetadata, _Mapping]] = ...,
    ) -> None: ...

class DetailServiceRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DetailServiceRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DetailServiceRequestBody, _Mapping]] = ...,
    ) -> None: ...

class DetailServiceRequestBody(_message.Message):
    __slots__ = ("did", "version")
    DID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    did: str
    version: int
    def __init__(self, did: _Optional[str] = ..., version: _Optional[int] = ...) -> None: ...

class DetailServiceResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DetailServiceResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DetailServiceResponseBody, _Mapping]] = ...,
    ) -> None: ...

class DetailServiceResponseBody(_message.Message):
    __slots__ = ("status", "service")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    service: _model_pb2.ServiceMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        service: _Optional[_Union[_model_pb2.ServiceMetadata, _Mapping]] = ...,
    ) -> None: ...

class SearchServiceRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: SearchServiceRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[SearchServiceRequestBody, _Mapping]] = ...,
    ) -> None: ...

class SearchServiceRequestBody(_message.Message):
    __slots__ = ("condition", "page")
    CONDITION_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    condition: SearchServiceCondition
    page: _message_pb2.RequestPage
    def __init__(
        self,
        condition: _Optional[_Union[SearchServiceCondition, _Mapping]] = ...,
        page: _Optional[_Union[_message_pb2.RequestPage, _Mapping]] = ...,
    ) -> None: ...

class SearchServiceCondition(_message.Message):
    __slots__ = ("code", "owner", "name", "keyword")
    CODE_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    KEYWORD_FIELD_NUMBER: _ClassVar[int]
    code: _code_pb2.ServiceCodeEnum
    owner: str
    name: str
    keyword: str
    def __init__(
        self,
        code: _Optional[_Union[_code_pb2.ServiceCodeEnum, str]] = ...,
        owner: _Optional[str] = ...,
        name: _Optional[str] = ...,
        keyword: _Optional[str] = ...,
    ) -> None: ...

class SearchServiceResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: SearchServiceResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[SearchServiceResponseBody, _Mapping]] = ...,
    ) -> None: ...

class SearchServiceResponseBody(_message.Message):
    __slots__ = ("status", "services", "page")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SERVICES_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    services: _containers.RepeatedCompositeFieldContainer[_model_pb2.ServiceMetadata]
    page: _message_pb2.ResponsePage
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        services: _Optional[_Iterable[_Union[_model_pb2.ServiceMetadata, _Mapping]]] = ...,
        page: _Optional[_Union[_message_pb2.ResponsePage, _Mapping]] = ...,
    ) -> None: ...

class OnlineServiceRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: OnlineServiceRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[OnlineServiceRequestBody, _Mapping]] = ...,
    ) -> None: ...

class OnlineServiceRequestBody(_message.Message):
    __slots__ = ("did", "version")
    DID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    did: str
    version: int
    def __init__(self, did: _Optional[str] = ..., version: _Optional[int] = ...) -> None: ...

class OnlineServiceResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: OnlineServiceResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[OnlineServiceResponseBody, _Mapping]] = ...,
    ) -> None: ...

class OnlineServiceResponseBody(_message.Message):
    __slots__ = ("status", "service")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    service: _model_pb2.ServiceMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        service: _Optional[_Union[_model_pb2.ServiceMetadata, _Mapping]] = ...,
    ) -> None: ...

class OfflineServiceRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: OfflineServiceRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[OfflineServiceRequestBody, _Mapping]] = ...,
    ) -> None: ...

class OfflineServiceRequestBody(_message.Message):
    __slots__ = ("did", "version")
    DID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    did: str
    version: int
    def __init__(self, did: _Optional[str] = ..., version: _Optional[int] = ...) -> None: ...

class OfflineServiceResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: OfflineServiceResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[OfflineServiceResponseBody, _Mapping]] = ...,
    ) -> None: ...

class OfflineServiceResponseBody(_message.Message):
    __slots__ = ("status", "service")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    service: _model_pb2.ServiceMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        service: _Optional[_Union[_model_pb2.ServiceMetadata, _Mapping]] = ...,
    ) -> None: ...

class DeleteServiceRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DeleteServiceRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DeleteServiceRequestBody, _Mapping]] = ...,
    ) -> None: ...

class DeleteServiceRequestBody(_message.Message):
    __slots__ = ("did", "version")
    DID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    did: str
    version: int
    def __init__(self, did: _Optional[str] = ..., version: _Optional[int] = ...) -> None: ...

class DeleteServiceResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DeleteServiceResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DeleteServiceResponseBody, _Mapping]] = ...,
    ) -> None: ...

class DeleteServiceResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/apps/zuoyepigai/meta.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/apps/zuoyepigai/meta.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.apps.zuoyepigai import imagecontent_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_imagecontent__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n%yeying/api/apps/zuoyepigai/meta.proto\x12\x1ayeying.api.apps.zuoyepigai\x1a-yeying/api/apps/zuoyepigai/imagecontent.proto"\x9e\x01\n\rGroupMetaData\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x0b\n\x03\x64id\x18\x02 \x01(\t\x12\x11\n\tgroupName\x18\x03 \x01(\t\x12\x11\n\tcreatedAt\x18\x04 \x01(\x03\x12\x11\n\tupdatedAt\x18\x05 \x01(\x03\x12\x11\n\tisDeleted\x18\x06 \x01(\x08\x12\x12\n\nteacherDid\x18\x07 \x01(\t\x12\x13\n\x0bstudentName\x18\x08 \x01(\t"\xd0\x01\n\x0f\x41rchiveMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nstudentDid\x18\x03 \x01(\t\x12\x12\n\nteacherDid\x18\x04 \x01(\t\x12\x0f\n\x07subject\x18\x05 \x01(\t\x12\x11\n\tcreatedAt\x18\x06 \x01(\x03\x12\x11\n\tupdatedAt\x18\x07 \x01(\x03\x12\x11\n\tisDeleted\x18\x08 \x01(\x08\x12\x11\n\ttelephone\x18\t \x01(\t\x12\r\n\x05\x65mail\x18\n \x01(\t\x12\x0e\n\x06status\x18\x0b \x01(\t"\x8c\x01\n\x10HomeworkMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x0b\n\x03\x64id\x18\x02 \x01(\t\x12\x0f\n\x07subject\x18\x03 \x01(\t\x12\x14\n\x0ctestPaperUid\x18\x04 \x01(\t\x12\x11\n\tcreatedAt\x18\x05 \x01(\x03\x12\x11\n\tupdatedAt\x18\x06 \x01(\x03\x12\x11\n\tisDeleted\x18\x07 \x01(\x08"z\n\x10MistakesMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x10\n\x08question\x18\x02 \x01(\t\x12\x0e\n\x06\x61nswer\x18\x03 \x01(\t\x12\x11\n\tcreatedAt\x18\x04 \x01(\x03\x12\x11\n\tupdatedAt\x18\x05 \x01(\x03\x12\x11\n\tisDeleted\x18\x06 \x01(\x08"\x85\x01\n\x0fMessageMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12\x11\n\tcreatedAt\x18\x05 \x01(\x03\x12\x11\n\tupdatedAt\x18\x06 \x01(\x03\x12\x11\n\tisDeleted\x18\x07 \x01(\x08"\x8c\x02\n\x0cTaskMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06tagUid\x18\x04 \x01(\t\x12\x0b\n\x03\x64id\x18\x05 \x01(\t\x12\x16\n\x0estudentDidList\x18\x06 \x01(\t\x12\x11\n\tcreatedAt\x18\x07 \x01(\x03\x12\x11\n\tupdatedAt\x18\x08 \x01(\x03\x12\x11\n\tstartTime\x18\t \x01(\x03\x12\x0f\n\x07\x65ndTime\x18\n \x01(\x03\x12\x11\n\tisDeleted\x18\x0b \x01(\x08\x12:\n\x06status\x18\x0c \x01(\x0e\x32*.yeying.api.apps.zuoyepigai.TaskStatusEnum">\n\x0cTagCountMeta\x12\x0e\n\x06tagUid\x18\x01 \x01(\t\x12\x0f\n\x07tagName\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x04"r\n\x0fTaskTagMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03\x64id\x18\x03 \x01(\t\x12\x11\n\tcreatedAt\x18\x04 \x01(\x03\x12\x11\n\tupdatedAt\x18\x05 \x01(\x03\x12\x11\n\tisDeleted\x18\x06 \x01(\x08"\x94\x02\n\x11WarehouseMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x0b\n\x03\x64id\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12<\n\x0burlMetaData\x18\x04 \x03(\x0b\x32\'.yeying.api.apps.zuoyepigai.UrlMetaData\x12\x0f\n\x07taskUid\x18\x05 \x01(\t\x12>\n\x04type\x18\x06 \x01(\x0e\x32\x30.yeying.api.apps.zuoyepigai.ImageContentTypeEnum\x12\x11\n\tcreatedAt\x18\x07 \x01(\x03\x12\x11\n\tupdatedAt\x18\x08 \x01(\x03\x12\x11\n\tisDeleted\x18\t \x01(\x08\x12\x10\n\x08urlIndex\x18\n \x01(\r")\n\x0bUrlMetaData\x12\r\n\x05index\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\tB\x1cZ\x1ayeying/api/apps/zuoyepigaib\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.apps.zuoyepigai.meta_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\032yeying/api/apps/zuoyepigai"
    _globals["_GROUPMETADATA"]._serialized_start = 117
    _globals["_GROUPMETADATA"]._serialized_end = 275
    _globals["_ARCHIVEMETADATA"]._serialized_start = 278
    _globals["_ARCHIVEMETADATA"]._serialized_end = 486
    _globals["_HOMEWORKMETADATA"]._serialized_start = 489
    _globals["_HOMEWORKMETADATA"]._serialized_end = 629
    _globals["_MISTAKESMETADATA"]._serialized_start = 631
    _globals["_MISTAKESMETADATA"]._serialized_end = 753
    _globals["_MESSAGEMETADATA"]._serialized_start = 756
    _globals["_MESSAGEMETADATA"]._serialized_end = 889
    _globals["_TASKMETADATA"]._serialized_start = 892
    _globals["_TASKMETADATA"]._serialized_end = 1160
    _globals["_TAGCOUNTMETA"]._serialized_start = 1162
    _globals["_TAGCOUNTMETA"]._serialized_end = 1224
    _globals["_TASKTAGMETADATA"]._serialized_start = 1226
    _globals["_TASKTAGMETADATA"]._serialized_end = 1340
    _globals["_WAREHOUSEMETADATA"]._serialized_start = 1343
    _globals["_WAREHOUSEMETADATA"]._serialized_end = 1619
    _globals["_URLMETADATA"]._serialized_start = 1621
    _globals["_URLMETADATA"]._serialized_end = 1662
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yeying.api.llm import provider_pb2 as yeying_dot_api_dot_llm_dot_provider__pb2

GRPC_GENERATED_VERSION = "1.68.1"
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower

    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f"The grpc package installed is at version {GRPC_VERSION},"
        + f" but the generated code in yeying/api/llm/provider_pb2_grpc.py depends on"
        + f" grpcio>={GRPC_GENERATED_VERSION}."
        + f" Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}"
        + f" or downgrade your generated code using grpcio-tools<={GRPC_VERSION}."
    )


class ProviderStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Descriptions = channel.unary_unary(
            "/yeying.api.llm.Provider/Descriptions",
            request_serializer=yeying_dot_api_dot_llm_dot_provider__pb2.ProviderDescriptionsRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_llm_dot_provider__pb2.ProviderDescriptionsResponse.FromString,
            _registered_method=True,
        )
        self.Models = channel.unary_unary(
            "/yeying.api.llm.Provider/Models",
            request_serializer=yeying_dot_api_dot_llm_dot_provider__pb2.ProviderModelsRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_llm_dot_provider__pb2.ProviderModelsResponse.FromString,
            _registered_method=True,
        )
        self.Search = channel.unary_unary(
            "/yeying.api.llm.Provider/Search",
            request_serializer=yeying_dot_api_dot_llm_dot_provider__pb2.SearchProviderRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_llm_dot_provider__pb2.SearchProviderResponse.FromString,
            _registered_method=True,
        )
        self.Detail = channel.unary_unary(
            "/yeying.api.llm.Provider/Detail",
            request_serializer=yeying_dot_api_dot_llm_dot_provider__pb2.ProviderDetailRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_llm_dot_provider__pb2.ProviderDetailResponse.FromString,
            _registered_method=True,
        )
        self.Add = channel.unary_unary(
            "/yeying.api.llm.Provider/Add",
            request_serializer=yeying_dot_api_dot_llm_dot_provider__pb2.AddProviderRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_llm_dot_provider__pb2.AddProviderResponse.FromString,
            _registered_method=True,
        )
        self.Delete = channel.unary_unary(
            "/yeying.api.llm.Provider/Delete",
            request_serializer=yeying_dot_api_dot_llm_dot_provider__pb2.DeleteProviderRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_llm_dot_provider__pb2.DeleteProviderResponse.FromString,
            _registered_method=True,
        )


class ProviderServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Descriptions(self, request, context):
        """供应商描述列表"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Models(self, request, context):
        """供应商模型"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Search(self, request, context):
        """搜索添加的供应商"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Detail(self, request, context):
        """供应商状态"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Add(self, request, context):
        """添加新供应商配置"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Delete(self, request, context):
        """删除供应商"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_ProviderServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Descriptions": grpc.unary_unary_rpc_method_handler(
            servicer.Descriptions,
            request_deserializer=yeying_dot_api_dot_llm_dot_provider__pb2.ProviderDescriptionsRequest.FromString,
            response_serializer=yeying_dot_api_dot_llm_dot_provider__pb2.ProviderDescriptionsResponse.SerializeToString,
        ),
        "Models": grpc.unary_unary_rpc_method_handler(
            servicer.Models,
            request_deserializer=yeying_dot_api_dot_llm_dot_provider__pb2.ProviderModelsRequest.FromString,
            response_serializer=yeying_dot_api_dot_llm_dot_provider__pb2.ProviderModelsResponse.SerializeToString,
        ),
        "Search": grpc.unary_unary_rpc_method_handler(
            servicer.Search,
            request_deserializer=yeying_dot_api_dot_llm_dot_provider__pb2.SearchProviderRequest.FromString,
            response_serializer=yeying_dot_api_dot_llm_dot_provider__pb2.SearchProviderResponse.SerializeToString,
        ),
        "Detail": grpc.unary_unary_rpc_method_handler(
            servicer.Detail,
            request_deserializer=yeying_dot_api_dot_llm_dot_provider__pb2.ProviderDetailRequest.FromString,
            response_serializer=yeying_dot_api_dot_llm_dot_provider__pb2.ProviderDetailResponse.SerializeToString,
        ),
        "Add": grpc.unary_unary_rpc_method_handler(
            servicer.Add,
            request_deserializer=yeying_dot_api_dot_llm_dot_provider__pb2.AddProviderRequest.FromString,
            response_serializer=yeying_dot_api_dot_llm_dot_provider__pb2.AddProviderResponse.SerializeToString,
        ),
        "Delete": grpc.unary_unary_rpc_method_handler(
            servicer.Delete,
            request_deserializer=yeying_dot_api_dot_llm_dot_provider__pb2.DeleteProviderRequest.FromString,
            response_serializer=yeying_dot_api_dot_llm_dot_provider__pb2.DeleteProviderResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("yeying.api.llm.Provider", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("yeying.api.llm.Provider", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class Provider(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Descriptions(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.llm.Provider/Descriptions",
            yeying_dot_api_dot_llm_dot_provider__pb2.ProviderDescriptionsRequest.SerializeToString,
            yeying_dot_api_dot_llm_dot_provider__pb2.ProviderDescriptionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Models(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.llm.Provider/Models",
            yeying_dot_api_dot_llm_dot_provider__pb2.ProviderModelsRequest.SerializeToString,
            yeying_dot_api_dot_llm_dot_provider__pb2.ProviderModelsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Search(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.llm.Provider/Search",
            yeying_dot_api_dot_llm_dot_provider__pb2.SearchProviderRequest.SerializeToString,
            yeying_dot_api_dot_llm_dot_provider__pb2.SearchProviderResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Detail(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.llm.Provider/Detail",
            yeying_dot_api_dot_llm_dot_provider__pb2.ProviderDetailRequest.SerializeToString,
            yeying_dot_api_dot_llm_dot_provider__pb2.ProviderDetailResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Add(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.llm.Provider/Add",
            yeying_dot_api_dot_llm_dot_provider__pb2.AddProviderRequest.SerializeToString,
            yeying_dot_api_dot_llm_dot_provider__pb2.AddProviderResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Delete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.llm.Provider/Delete",
            yeying_dot_api_dot_llm_dot_provider__pb2.DeleteProviderRequest.SerializeToString,
            yeying_dot_api_dot_llm_dot_provider__pb2.DeleteProviderResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )
